@@ -33,8 +33,7 @@
 
 using namespace Akregator;
 
-K_PLUGIN_FACTORY_WITH_JSON(KCMAkregatorAppearanceConfigFactory, "akregator_config_appearance.json", registerPlugin<KCMAkregatorAppearanceConfig>();
-                           )
+K_PLUGIN_CLASS_WITH_JSON(KCMAkregatorAppearanceConfig, "akregator_config_appearance.json")
 
 KCMAkregatorAppearanceConfig::KCMAkregatorAppearanceConfig(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
