@@ -50,6 +50,7 @@
 #include "akregator_options.h"
 #include <Libkdepim/BroadcastStatus>
 #include "akregator-version.h"
+#include "unityservicemanager.h"
 #include <kio/filecopyjob.h>
 #include <knotifyconfigwidget.h>
 #include <kaboutdata.h>
@@ -242,21 +243,14 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     // notify the part that this is our internal widget
     setWidget(mCentralWidget);
 
+    //Initialize instance.
+    (void)UnityServiceManager::instance();
+    connect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, UnityServiceManager::instance(), &UnityServiceManager::slotSetUnread);
+
     if (Settings::showTrayIcon() && !TrayIcon::getInstance()) {
-        TrayIcon *trayIcon = new TrayIcon(m_mainWidget->window());
-        TrayIcon::setInstance(trayIcon);
-        m_actionManager->setTrayIcon(trayIcon);
-
-        if (isTrayIconEnabled()) {
-            trayIcon->setStatus(KStatusNotifierItem::Active);
-        }
-
+        initializeTrayIcon();
         QWidget *const notificationParent = isTrayIconEnabled() ? m_mainWidget->window() : nullptr;
         NotificationManager::self()->setWidget(notificationParent, componentData().componentName());
-
-        connect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, trayIcon, &TrayIcon::slotSetUnread);
-        connect(m_mainWidget.data(), &MainWidget::signalArticlesSelected,
-                this, &Part::signalArticlesSelected);
     }
 
     connect(qApp, &QCoreApplication::aboutToQuit, this, &Part::slotOnShutdown);
@@ -330,30 +324,37 @@ void Part::slotOnShutdown()
     delete TrayIcon::getInstance();
     TrayIcon::setInstance(nullptr);
     delete m_storage;
-    m_storage = 0;
+    m_storage = nullptr;
     //delete m_actionManager;
 }
 
+void Part::initializeTrayIcon()
+{
+    TrayIcon *trayIcon = new TrayIcon(m_mainWidget->window());
+    TrayIcon::setInstance(trayIcon);
+    m_actionManager->setTrayIcon(trayIcon);
+
+    if (isTrayIconEnabled()) {
+        trayIcon->setStatus(KStatusNotifierItem::Active);
+    }
+
+    connect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, trayIcon, &TrayIcon::slotSetUnread);
+    connect(m_mainWidget.data(), &MainWidget::signalArticlesSelected,
+            this, &Part::signalArticlesSelected);
+
+    m_mainWidget->slotSetTotalUnread();
+}
+
 void Part::slotSettingsChanged()
 {
     NotificationManager::self()->setWidget(isTrayIconEnabled() ? m_mainWidget->window() : nullptr, componentData().componentName());
 
-    if (Settings::showTrayIcon() && !TrayIcon::getInstance()) {
-        TrayIcon *trayIcon = new TrayIcon(m_mainWidget->window());
-        TrayIcon::setInstance(trayIcon);
-        m_actionManager->setTrayIcon(trayIcon);
-
-        if (isTrayIconEnabled()) {
-            trayIcon->setStatus(KStatusNotifierItem::Active);
+    if (Settings::showTrayIcon()) {
+        if (!TrayIcon::getInstance()) {
+            initializeTrayIcon();
+            m_mainWidget->slotSetTotalUnread();
         }
-
-        connect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, trayIcon, &TrayIcon::slotSetUnread);
-        connect(m_mainWidget.data(), &MainWidget::signalArticlesSelected,
-                this, &Part::signalArticlesSelected);
-
-        m_mainWidget->slotSetTotalUnread();
-    }
-    if (!Settings::showTrayIcon()) {
+    } else {
         TrayIcon::getInstance()->disconnect();
         delete TrayIcon::getInstance();
         TrayIcon::setInstance(nullptr);
@@ -362,14 +363,15 @@ void Part::slotSettingsChanged()
 
     Syndication::FileRetriever::setUseCache(Settings::useHTMLCache());
 
-    QStringList fonts;
-    fonts.append(Settings::standardFont());
-    fonts.append(Settings::fixedFont());
-    fonts.append(Settings::sansSerifFont());
-    fonts.append(Settings::serifFont());
-    fonts.append(Settings::standardFont());
-    fonts.append(Settings::standardFont());
-    fonts.append(QStringLiteral("0"));
+    const QStringList fonts {
+        Settings::standardFont(),
+        Settings::fixedFont(),
+        Settings::sansSerifFont(),
+        Settings::serifFont(),
+        Settings::standardFont(),
+        Settings::standardFont(),
+        QStringLiteral("0")
+    };
     Settings::setFonts(fonts);
 
     if (Settings::minimumFontSize() > Settings::mediumFontSize()) {
