@@ -81,7 +81,7 @@ public:
     Part(QWidget *parentWidget, QObject *parent, const QVariantList &);
 
     /** Destructor. */
-    ~Part();
+    ~Part() override;
 
     /**
         Opens feedlist
@@ -206,6 +206,7 @@ private: // methods
     void clearCrashProperties();
 
 private: // attributes
+    void initializeTrayIcon();
 
     class ApplyFiltersInterceptor;
     ApplyFiltersInterceptor *m_applyFiltersInterceptor = nullptr;
