@@ -346,7 +346,7 @@ void MainWidget::slotOnShutdown()
 
     delete m_mainTab;
     delete m_mainFrame;
-    m_mainFrame = 0;
+    m_mainFrame = nullptr;
 
     Settings::self()->save();
 }
@@ -1102,7 +1102,11 @@ void MainWidget::slotArticleDelete()
 void MainWidget::slotFramesChanged()
 {
     // We need to wait till the frame is fully loaded
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    QMetaObject::invokeMethod(m_part, &Akregator::Part::slotAutoSave, Qt::QueuedConnection);
+#else
     QMetaObject::invokeMethod(m_part, "slotAutoSave", Qt::QueuedConnection);
+#endif
 }
 
 void MainWidget::slotArticleToggleKeepFlag(bool)
